﻿* Encoding: UTF-8.
*=========================================================================*
* ESTADÍSTICAS DE EDIFICACIONES ( PERMISOS DE CONSTRUCCIÓN) 2021.
*=========================================================================*

*=========================================================================*
1.  ENCABEZADO DE SINTAXIS
*=========================================================================*

* TÍTULO DE LA SINTAXIS:
* Cálculo de indicadores ESED2021

* OPERACIÓN ESTADÍSTICA:
* Estadísticas de edificaciones- Permisos de construcción

* ENTIDAD EJECUTORA:
* Instituto Nacional de Estadística y Censos (INEC)

* DIRECCIÓN TÉCNICA RESPONSABLE:
* Dirección de Estadísticas Económicas (DECON)

********************************************************************************************************
* Fecha de elaboración:        6 de julio del 2022
* Fecha última modificación:  26 de julio del 2022
********************************************************************************************************
*Software estadístico: SPSS 24
********************************************************************************************************
*Elaborado por:
* Unidad de Gestión de Estadísticas Estructurales (GESE).
* Lorena Ramos.
* Valery Paz y Miño

********************************************************************************************************
* Revisado por:
* Roberto Chaves
* Jefe de Gestión de Estadísticas Estructurales (GESE)
* Instituto Nacional de Estadística y Censos
* 
********************************************************************************************************
* Aprobado por: 
* Diana Barco
* Directora de Estadísticas Económicas (DECON)
* Instituto Nacional de Estadística y Censos 
*Diana_Barco@inec.gob.ec
********************************************************************************************************
*Instrucciones:
 *1.- Descargar la base de datos de las Estadísticas de Edificaciones "7. 2021_ESED_BDD.sav " en formato SPSS de la página web del INEC (https://www.ecuadorencifras.gob.ec/edificaciones/).
 *2.- Guardar y abrir la base de datos "7. 2021_ESED_BDD.sav "
 *3.- En el disco C: de su computadora, crear una carpeta llamada "Tabulados ESED". En esta carpeta se exportarán los resultados de los indicadores. 


*=========================================================================*
*2.  CÓDIGO DE LA SINTAXIS
*=========================================================================*

*Ingreso de la población proyectada 2021.

NUMERIC POBLACION (f10.0).
IF(codprovf="01") POBLACION =  895503.
IF(codprovf="02") POBLACION =  211413.
IF(codprovf="03") POBLACION =  285960.
IF(codprovf="04") POBLACION =  188167.
IF(codprovf="05") POBLACION =  494716.
IF(codprovf="06") POBLACION =  528104.
IF(codprovf="07") POBLACION =  724193.
IF(codprovf="08") POBLACION =  651917.
IF(codprovf="09") POBLACION =  4446641.
IF(codprovf="10") POBLACION =  482326.
IF(codprovf="11") POBLACION =  525984.
IF(codprovf="12") POBLACION =  932593.
IF(codprovf="13") POBLACION =  1573950.
IF(codprovf="14") POBLACION =  200737.
IF(codprovf="15") POBLACION =  136434.
IF(codprovf="16") POBLACION =  117155.
IF(codprovf="17") POBLACION =  3284186.
IF(codprovf="18") POBLACION =  597011.
IF(codprovf="19") POBLACION =  122921.
IF(codprovf="20") POBLACION =  33769.
IF(codprovf="21") POBLACION =  235537.
IF(codprovf="22") POBLACION =  163095.
IF(codprovf="23") POBLACION =  466423.
IF(codprovf="24") POBLACION =  409810.
IF(codprovf="90") POBLACION =  44582.
EXECUTE.
VARIABLE LABELS POBLACION 'Población proyectada 2021'.

*========================================================*
* INDICADOR 1: Número de viviendas a construir por cada 10 mil habitantes, según provincias.
*========================================================*
***Cálculo del indicador***. 

NUMERIC   viv_10000hab (f10).
compute viv_10000hab=(CNUVICAL)/POBLACION*10000.
EXECUTE   .
VARIABLE LABELS   viv_10000hab 'Viviendas a construir por 10000 habitantes'. 

***Agregar el indicador calculado según provincia**.

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=codprovf
  /viv_10000hab_agre=sum(viv_10000hab).

COMPUTE viv_10000hab= viv_10000hab_agre.
EXECUTE.
DELETE VARIABLES viv_10000hab_agre. 

***Generar tablas y exportar ***

***CUADRO F1***.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=codprovf viv_10000hab CNUVICAL POBLACION DISPLAY=BOTH
  /TABLE codprovf [C] BY CNUVICAL [S][SUM] + POBLACION [S][MEAN] + viv_10000hab [S][MEAN] 
  /CATEGORIES VARIABLES=codprovf ORDER=A KEY=VALUE EMPTY=EXCLUDE  TOTAL=YES
  /TITLES
    TITLE='VIVIENDAS A CONSTRUIR POR CADA 10.000 HABITANTES año 2021 '
'POR PROVINCIAS'
'(NÚMERO)'
    CAPTION='FUENTE: INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - EDIFICACIONES 2021'.

OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados ESED\2021_INDICADORES'
     OPERATION=CREATESHEET  SHEET='C-F1'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *. 

*========================================================*
* INDICADOR 2: Promedio de metros cuadrados a construir por vivienda, según provincias.
*========================================================*

* Se filtra la base de datos de manera que se considera únicamente a las nuevas construcciones para uso residencial.

USE ALL.
COMPUTE filterCARES_$=(CTIPOBR=1 & CARES>0 & CNUVICAL>0).
VARIABLE LABELS filterCARES_$ 'CTIPOBR=1'.
VALUE LABELS filterCARES_$ 0 'Not Selected' 1 'Selected'.
FORMATS filterCARES_$ (f1.0).
FILTER BY filterCARES_$.
EXECUTE. 

***Cálculo del indicador***.

compute Area_viv=CARES/CNUVICAL.
EXECUTE.
VARIABLE LABELS  Area_viv 'Área por vivienda'. 

***Generar tablas y exportar ***.

***CUADRO N° F2***.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=codprovf  Area_viv DISPLAY=LABEL
  /TABLE codprovf [C] BY Area_viv [S][MEAN]
  /CATEGORIES VARIABLES=codprovf ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES POSITION=AFTER
  /TITLES
    TITLE='Promedio de metros cuadrados por vivienda, año 2021'
'POR PROVINCIAS'
'(PROMEDIO DE METROS CUADRADOS)'
    CAPTION='FUENTE: INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - EDIFICACIONES 2021'.

OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados ESED\2021_INDICADORES'
     OPERATION=CREATESHEET  SHEET='C-F2'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *.

FILTER OFF.
DELETE VARIABLES Area_viv. 


*==========================================================*
* INDICADOR 3: Costo de construcción proyectado por metro cuadrado, según uso de la edificación y por provincias.
*==========================================================*

***Cálculo del indicador ***.

compute VALOR_PROMEDIO=CVAE/CARCO.
execute.
formats VALOR_PROMEDIO (f15.0).
var label VALOR_PROMEDIO 'Valor promedio de la edificación por metro cuadrado'. 
FREQUENCIES VALOR_PROMEDIO.

***Generar tablas y exportar ***

***C-F3***.

* Tablas personalizadas.

CTABLES
  /VLABELS VARIABLES=CDISPUSO codprovf VALOR_PROMEDIO DISPLAY=LABEL
  /TABLE CDISPUSO BY codprovf [C] > VALOR_PROMEDIO [S][MEAN]
  /CATEGORIES VARIABLES=CDISPUSO codprovf ORDER=A KEY=VALUE EMPTY=INCLUDE TOTAL=YES
  /TITLES
    TITLE='Valor promedio de la edificación por metro cuadrado, año 2021'
'POR USO DE LA EDIFICACIÓN Y POR PROVINCIA'
'(Dólares americános)'
    CAPTION='FUENTE: INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - EDIFICACIONES 2021'.


OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados ESED\2021_INDICADORES '
     OPERATION=CREATESHEET  SHEET='C-F3'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *.


*==========================================================*
* INDICADOR 4: Metros cuadrados a construir por cada 100 habitantes, según provincias.
*==========================================================*

***Cálculo del indicador ***.

compute m2_100hab=(CARES)/POBLACION*100.
EXECUTE.
VARIABLE LABELS m2_100hab 'Metros cuadrados a construir por 100 habitantes'.

***Agregar el indicador calculado según provincia**.

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=codprovf
  /m2_100hab_agre=sum(m2_100hab).

COMPUTE m2_100hab= m2_100hab_agre.
EXECUTE.
DELETE VARIABLES m2_100hab_agre.

***Generar tablas y exportar ***

***C-F4***.

* Tablas personalizadas.
CTABLES
  /VLABELS VARIABLES=codprovf m2_100hab CARES POBLACION DISPLAY=BOTH
  /TABLE codprovf [C] BY CARES [S][SUM] + POBLACION [S][MEAN] + m2_100hab [S][MEAN] 
  /CATEGORIES VARIABLES=codprovf ORDER=A KEY=VALUE EMPTY=EXCLUDE TOTAL=YES
  /TITLES
    TITLE='METROS CUADRADOS A CONSTRUIR POR CADA 100 HABITANTES año 2021'
'POR PROVINCIAS'
'(METROS CUADRADOS)'
    CAPTION='FUENTE: INSTITUTO NACIONAL DE ESTADÍSTICA Y CENSOS (INEC) - EDIFICACIONES 2021'.

OUTPUT EXPORT
  /CONTENTS  EXPORT=VISIBLE  LAYERS=PRINTSETTING  MODELVIEWS=PRINTSETTING
  /XLSX  DOCUMENTFILE='C:\Tabulados ESED\2021_INDICADORES'
     OPERATION=CREATESHEET  SHEET='C-F4'
     LOCATION=LASTCOLUMN  NOTESCAPTIONS=YES.
OUTPUT CLOSE *.
